@@ -21,8 +21,8 @@
 */
 
 // QCA
-// need to have this first, as QCA needs QT_NO_CAST_FROM_ASCII disabled when 
-#include <config-qca2.h>
+// need to have this first, as QCA needs QT_NO_CAST_FROM_ASCII disabled when included
+#include <config-qca2.h> //krazy:excludeall=includes
 #ifdef HAVE_QCA2
 // disable QT_NO_CAST_FROM_ASCII
 #ifdef QT_NO_CAST_FROM_ASCII
@@ -51,7 +51,7 @@
 #include <KDebug>
 
 
-namespace Kasten
+namespace Kasten1
 {
 
 ChecksumTool::ChecksumTool()
@@ -104,7 +104,7 @@ void ChecksumTool::setTargetModel( AbstractModel* model )
 
     if( mByteArrayView && mByteArrayModel )
     {
-        connect( mByteArrayView,  SIGNAL(selectedDataChanged( const Kasten::AbstractModelSelection* )),
+        connect( mByteArrayView,  SIGNAL(selectedDataChanged(const Kasten1::AbstractModelSelection*)),
                  SLOT(onSelectionChanged()) );
     }
 
@@ -147,7 +147,7 @@ void ChecksumTool::calculateChecksum()
         mSourceAlgorithmId = mAlgorithmId;
         mSourceByteArrayModel = mByteArrayModel;
         mSourceSelection = mByteArrayView->selection();
-        connect( mSourceByteArrayModel,  SIGNAL(contentsChanged( const Okteta::ArrayChangeMetricsList& )),
+        connect( mSourceByteArrayModel,  SIGNAL(contentsChanged(Okteta::ArrayChangeMetricsList)),
                  SLOT(onSourceChanged()) );
         connect( mSourceByteArrayModel,  SIGNAL(destroyed()),
                  SLOT(onSourceDestroyed()) );
