@@ -24,17 +24,18 @@
 #define ABSTRACTSAVEDISCARDDIALOG_H
 
 // lib
+#include <kastencore_export.h>
 #include <kastencore.h>
 
 class QString;
 
 
-namespace Kasten
+namespace Kasten1
 {
 class AbstractDocument;
 
 
-class AbstractSaveDiscardDialog
+class KASTENCORE_EXPORT AbstractSaveDiscardDialog
 {
   public:
     virtual ~AbstractSaveDiscardDialog();
