@@ -116,8 +116,10 @@ UMLListViewItem::UMLListViewItem(UMLListViewItem * parent, const QString &name,
         updateObject();
         m_id = o->id();
     }
-//    setRenameEnabled(0, !Model_Utils::typeIsRootView(t));
     setText(name);
+    if (!Model_Utils::typeIsRootView(t)) {
+        setFlags(flags() | Qt::ItemIsEditable);
+    }
 }
 
 /**
@@ -166,7 +168,7 @@ UMLListViewItem::UMLListViewItem(UMLListViewItem * parent, const QString &name,
     //  to set pixmap to folder.  doesn't hurt diagrams.
     updateFolder();
     setText(name);
-    //setRenameEnabled(0, true);
+    setFlags(flags() | Qt::ItemIsEditable);
 }
 
 /**
@@ -434,10 +436,9 @@ void UMLListViewItem::setText(int column, const QString &newText)
 }
 
 /**
- * Returns the current text.
- * :TODO: not used anywhere
+ * Returns the saved text.
  */
-QString UMLListViewItem::getText() const
+QString UMLListViewItem::getSavedText() const
 {
     return m_label;
 }
@@ -450,6 +451,10 @@ void UMLListViewItem::setCreating( bool creating )
     m_bCreating = creating;
 }
 
+bool UMLListViewItem::creating() const {
+    return m_bCreating;
+}
+
 /**
  * Set the pixmap corresponding to the given IconType.
  */
@@ -466,10 +471,6 @@ void UMLListViewItem::startRename(int col)
 {
     DEBUG(DBG_LVI) << this << " - column=" << col << ", text=" << text(col);
     m_label = text(col);  // keep the old text
-    if (m_bCreating) {
-        UMLListView* listView = static_cast<UMLListView*>(treeWidget());
-        listView->cancelRename(this);
-    }
 }
 
 /**
