@@ -25,11 +25,11 @@
 #include "object_factory.h"
 
 ClassifierWidget::ClassifierWidget(UMLScene * scene, UMLClassifier *c)
-  : UMLWidget(scene, c)
+  : UMLWidget(scene, WidgetBase::wt_Class, c)
 {
     init();
     if (c != NULL && c->isInterface()) {
-        WidgetBase::setBaseType(WidgetBase::wt_Interface);
+        setBaseType(WidgetBase::wt_Interface);
         m_showStereotype = true;
         m_showAttributes = false;
         updateSigs();
@@ -47,8 +47,6 @@ const int ClassifierWidget::CIRCLE_SIZE = 30;
 
 void ClassifierWidget::init()
 {
-    WidgetBase::setBaseType(WidgetBase::wt_Class);
-
     const Settings::OptionState& ops = m_scene->optionState();
     m_showAccess = ops.classState.showVisibility;
     m_showOperations = ops.classState.showOps;
@@ -321,10 +319,10 @@ int ClassifierWidget::displayedOperations()
     return displayedMembers(UMLObject::ot_Operation);
 }
 
-QSize ClassifierWidget::calculateSize()
+UMLSceneSize ClassifierWidget::minimumSize()
 {
     if (!m_pObject) {
-        return UMLWidget::calculateSize();
+        return UMLWidget::minimumSize();
     }
     if (classifier()->isInterface() && m_drawAsCircle) {
         return calculateAsCircleSize();
@@ -414,7 +412,7 @@ QSize ClassifierWidget::calculateSize()
     // allow for width margin
     width += MARGIN * 2;
 
-    return QSize(width, height);
+    return UMLSceneSize(width, height);
 }
 
 void ClassifierWidget::slotMenuSelection(QAction* action)
@@ -552,8 +550,8 @@ UMLClassifier *ClassifierWidget::classifier()
 void ClassifierWidget::paint(QPainter & p, int offsetX, int offsetY)
 {
     setPenFromSettings(p);
-    if ( UMLWidget::getUseFillColour() )
-        p.setBrush( UMLWidget::getFillColor() );
+    if ( UMLWidget::useFillColor() )
+        p.setBrush( UMLWidget::fillColor() );
     else
         p.setBrush( m_scene->viewport()->palette().color(QPalette::Background) );
 
@@ -789,7 +787,7 @@ void ClassifierWidget::adjustAssocs(int x, int y)
 {
     UMLWidget::adjustAssocs(x, y);
 
-    if (m_pDoc->loading() || m_pAssocWidget == 0) {
+    if (m_doc->loading() || m_pAssocWidget == 0) {
         return;
     }
 
