@@ -22,38 +22,40 @@
 #include "umlview.h"
 #include "umlobject.h"
 
+/**
+ * Constructs a PackageWidget.
+ *
+ * @param scene              The parent of this PackageWidget.
+ * @param o         The UMLObject this will be representing.
+ */
 PackageWidget::PackageWidget(UMLScene * scene, UMLPackage *o)
-  : UMLWidget(scene, o)
+  : UMLWidget(scene, WidgetBase::wt_Package, o)
 {
-    init();
-}
-
-void PackageWidget::init()
-{
-    UMLWidget::setBaseType(WidgetBase::wt_Package);
     setSize(100, 30);
     setZ(m_origZ = 1);  // above box but below UMLWidget because may embed widgets
-    m_pMenu = 0;
     //set defaults from m_scene
     if (m_scene) {
         //check to see if correct
         const Settings::OptionState& ops = m_scene->optionState();
         m_showStereotype = ops.classState.showStereoType;
     }
-    //maybe loading and this may not be set.
-    if (m_pObject && !UMLApp::app()->document()->loading())
-        updateComponentSize();
 }
 
+/**
+ * Destructor.
+ */
 PackageWidget::~PackageWidget()
 {
 }
 
+/**
+ * Overrides standard method.
+ */
 void PackageWidget::paint(QPainter & p, int offsetX, int offsetY)
 {
     setPenFromSettings(p);
-    if ( UMLWidget::getUseFillColour() )
-        p.setBrush( UMLWidget::getFillColor() );
+    if ( UMLWidget::useFillColor() )
+        p.setBrush( UMLWidget::fillColor() );
     else
         p.setBrush( m_scene->viewport()->palette().color(QPalette::Background) );
 
@@ -99,10 +101,13 @@ void PackageWidget::paint(QPainter & p, int offsetX, int offsetY)
     }
 }
 
-QSize PackageWidget::calculateSize()
+/**
+ * Overrides method from UMLWidget
+ */
+UMLSceneSize PackageWidget::minimumSize()
 {
     if ( !m_pObject ) {
-        return UMLWidget::calculateSize();
+        return UMLWidget::minimumSize();
     }
 
     const QFontMetrics &fm = getFontMetrics(FT_BOLD_ITALIC);
@@ -125,13 +130,15 @@ QSize PackageWidget::calculateSize()
 
     int height = (lines*fontHeight) + fontHeight + (PACKAGE_MARGIN * 2);
 
-    return QSize(width, height);
+    return UMLSceneSize(width, height);
 }
 
+/**
+ * Saves to the "packagewidget" XMI element.
+ */
 void PackageWidget::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
 {
     QDomElement conceptElement = qDoc.createElement("packagewidget");
     UMLWidget::saveToXMI(qDoc, conceptElement);
     qElement.appendChild(conceptElement);
 }
-
