@@ -41,11 +41,9 @@
  * @param id                The ID to assign (-1 will prompt a new ID.)
  */
 SignalWidget::SignalWidget(UMLScene *scene, SignalType signalType, Uml::IDType id)
-  : UMLWidget(scene, id)
+  : UMLWidget(scene, WidgetBase::wt_Signal, id)
 {
-    UMLWidget::setBaseType(WidgetBase::wt_Signal);
     m_signalType = signalType;
-    updateComponentSize();
     m_pName = NULL;
     if (signalType == SignalWidget::Time) {
         m_pName = new FloatingTextWidget(scene, Uml::TextRole::Floating,"");
@@ -74,8 +72,8 @@ void SignalWidget::paint(QPainter & p, int offsetX, int offsetY)
     switch (m_signalType)
     {
     case Send :
-        if(UMLWidget::getUseFillColour())
-            p.setBrush(UMLWidget::getFillColor());
+        if(UMLWidget::useFillColor())
+            p.setBrush(UMLWidget::fillColor());
         {
 
             a.setPoints( 5, offsetX           ,offsetY,
@@ -99,8 +97,8 @@ void SignalWidget::paint(QPainter & p, int offsetX, int offsetY)
         }
         break;
     case Accept :
-        if(UMLWidget::getUseFillColour())
-            p.setBrush(UMLWidget::getFillColor());
+        if(UMLWidget::useFillColor())
+            p.setBrush(UMLWidget::fillColor());
         {
             a.setPoints( 5, offsetX ,      offsetY,
                             offsetX + w/3, (h/2)+offsetY,
@@ -124,8 +122,8 @@ void SignalWidget::paint(QPainter & p, int offsetX, int offsetY)
         }
         break;
     case Time :
-        if(UMLWidget::getUseFillColour())
-            p.setBrush(UMLWidget::getFillColor());
+        if(UMLWidget::useFillColor())
+            p.setBrush(UMLWidget::fillColor());
         {
             a.setPoints( 4, offsetX ,    offsetY,
                             offsetX + w, offsetY+h,
@@ -325,7 +323,7 @@ void SignalWidget::slotMenuSelection(QAction* action)
 /**
  * Overrides method from UMLWidget
  */
-QSize SignalWidget::calculateSize()
+UMLSceneSize SignalWidget::minimumSize()
 {
         int width = SIGNAL_WIDTH, height = SIGNAL_HEIGHT;
         const QFontMetrics &fm = getFontMetrics(FT_BOLD);
@@ -343,7 +341,7 @@ QSize SignalWidget::calculateSize()
         width  += SIGNAL_MARGIN * 2;
         height += SIGNAL_MARGIN * 2;
 
-    return QSize(width, height);
+    return UMLSceneSize(width, height);
 }
 
 #include "signalwidget.moc"
